@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- * Copyright 2012-2013 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2012-2014 Leandro Nini <drfiemost@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,9 +39,6 @@ private:
     uint_least16_t m_driverLength;
     uint_least16_t m_powerOnDelay;
 
-private:
-    static uint8_t psid_driver[];
-
 private:
     /**
      * Get required I/O map to reach address
@@ -65,18 +62,17 @@ public:
 
     /**
      * Relocate the driver.
-     *
-     * @param mem the c64 memory interface
      */
-    bool drvReloc(sidmemory *mem);
+    bool drvReloc();
 
     /**
      * Install the driver.
      * Must be called after the tune has been placed in memory.
      *
      * @param mem the c64 memory interface
+     * @param video the PAL/NTSC switch value, 0: NTSC, 1: PAL
      */
-    void install(sidmemory *mem) const;
+    void install(sidmemory *mem, uint8_t video) const;
 
     /**
      * Get a detailed error message.
